# istanbul-reports

[![Build Status](https://travis-ci.org/istanbuljs/istanbul-reports.svg?branch=main)](https://travis-ci.org/istanbuljs/istanbul-reports)

-   node.getRelativeName

-   context.getSource(filePath)
-   context.classForPercent(type, percent)
-   context.console.colorize(str, class)
-   context.writer
-   context.console.write
-   context.console.println
